iaupdate/IAD/ui/inc/iaupdateapplication.h
changeset 29 26b6f0522fd8
parent 0 ba25891c3a9e
child 33 8110bf1194d1
--- a/iaupdate/IAD/ui/inc/iaupdateapplication.h	Fri Apr 16 15:05:20 2010 +0300
+++ b/iaupdate/IAD/ui/inc/iaupdateapplication.h	Mon May 03 12:38:03 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2007-2008 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -11,56 +11,30 @@
 *
 * Contributors:
 *
 * Description:   This file contains the header file of the CIAUpdateApplication
 *                class 
 *
 */
 
-
-
-#ifndef __IAUPDATE_APPLICATION_H__
-#define __IAUPDATE_APPLICATION_H__
+#ifndef IAUPDATEAPPLICATION_H_
+#define IAUPDATEAPPLICATION_H_
 
-// INCLUDES
-#include <aknapp.h>
-
-#include "iaupdateuids.h"
+#include <QSharedPointer>
+#include <HbApplication.h>
 
-// CONSTANTS
-// UID for the application, this should correspond to the uid defined in the mmp file
-static const TUid KUidIAUpdateApp = { KIAUpdateUiUid };
-
+// forward declarations
+class IAUpdateEngine;
+class IAUpdateMainWindow;
 
-/**
-* CAppMngrApp application class.
-* Provides factory to create concrete document object and
-* application server object
-*/
-class CIAUpdateApplication : public CAknApplication
+class IAUpdateApplication : public HbApplication
     {
+public:
+    IAUpdateApplication(int argc, char* argv[]);
+    virtual ~IAUpdateApplication();
     
-private:  // from CAknApplication
-
-    /**
-    * Returns application's UID 
-    * @return The UID value 
-    */
-    TUid AppDllUid() const;
+private:
+    QSharedPointer<IAUpdateEngine> mEngine;         // owned
+    QSharedPointer<IAUpdateMainWindow> mMainWindow; // owned
+    };
 
-    /**
-    * From CApaApplication, creates CAppMngrDocument document object.
-    * @return A pointer to the created document object.
-    */
-    CApaDocument* CreateDocumentL();
-    
-    /**
-    * Creates application server.
-    * @param aAppServer Instance of application server class
-    */
-    void NewAppServerL( CApaAppServer*& aAppServer );
-    };
-    
-
-#endif // __IAUPDATE_APPLICATION_H__
-
-// End of File
\ No newline at end of file
+#endif /* IAUPDATEAPPLICATION_H_ */
@@ -11,56 +11,30 @@
 * Contributors:
 *
-* Description:   This file contains the header file of the CIAUpdateApplication
+* Description:   This file contains the header file of the IAUpdateApplication
 *                class 
 *